@@ -17,7 +17,7 @@
  */
 
 #define NL_MAJOR 2
-#define NL_MINOR 0
-#define NL_REV   10
-#define NL_DATE  "Sep 05, 2004"
-#define VERSION  "2.0.10"
+#define NL_MINOR 2
+#define NL_REV   2
+#define NL_DATE  "Mar 18, 2005"
+#define VERSION  "2.2.2"
